@@ -9,6 +9,7 @@ os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'db.settings')
 RUN_EVERY_15 = 60 * 15
 RUN_HOURLY = 60 * 60
 RUN_DAILY = 60 * 60 * 24
+RUN_EVERY_TWO_HOURS = 2 * 60 * 60
 
 APP = Celery('db')
 
@@ -25,6 +26,13 @@ def update_all_tle():
     periodic_task()
 
 
+@APP.task
+def update_tle_sets():
+    """Wrapper task for 'update_tle_sets' shared task"""
+    from db.base.tasks import update_tle_sets as periodic_task
+    periodic_task()
+
+
 @APP.task
 def background_cache_statistics():
     """Wrapper task for 'background_cache_statistics' shared task"""
@@ -51,6 +59,8 @@ def setup_periodic_tasks(sender, **kwargs):
     """Initializes celery tasks that need to run on a scheduled basis"""
     sender.add_periodic_task(RUN_DAILY, update_all_tle.s(), name='update-all-tle')
 
+    sender.add_periodic_task(RUN_EVERY_TWO_HOURS, update_tle_sets.s(), name='update-tle-sets')
+
     sender.add_periodic_task(
         RUN_HOURLY, background_cache_statistics.s(), name='background-cache-statistics'
     )
